@@ -1,3 +1,22 @@
+/*
+    Gri - A language for scientific graphics programming
+    Copyright (C) 2008 Daniel Kelley
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
 #include	<stdio.h>
 #include	<string.h>
 #include	<math.h>
@@ -160,7 +179,7 @@ show_licenseCmd()
 {
 	extern std::string _lib_directory;
 	std::string license(_lib_directory.c_str());
-	license.append("/license.txt");
+	license.append("doc/license.txt");
 	more_file_to_terminal(license.c_str());
 	return true;
 }
