@@ -1,3 +1,22 @@
+/*
+    Gri - A language for scientific graphics programming
+    Copyright (C) 2008 Daniel Kelley
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
 //#define TEST_POPT // uncomment this to test the POPT library
 
 #include	<string>
@@ -153,6 +172,7 @@ start_up(int argc, char **argv)
 {
 	extern rectangle _page_size;
 	_page_size.set(0.0, 0.0, 0.0, 0.0);
+
 /*
 #if defined(TEST_POPT)
 	printf("DEBUG: %s:%d: FYI, start_up() found the raw args to be:\n",__FILE__,__LINE__);
@@ -491,6 +511,7 @@ static void
 set_defaults()
 {
 	extern char      _xtype_map, _ytype_map;
+	
 	_contourFmt.assign(CONTOUR_FMT_DEFAULT);
 	_current_directory.assign(".");
 	// Set up various other defaults
